@@ -28,9 +28,9 @@ TEST_IMPL(loop_update_time) {
 
   start = uv_now(uv_default_loop());
   while (uv_now(uv_default_loop()) - start < 1000)
-    ASSERT_EQ(0, uv_run(uv_default_loop(), UV_RUN_NOWAIT));
+    ASSERT_OK(uv_run(uv_default_loop(), UV_RUN_NOWAIT));
 
-  MAKE_VALGRIND_HAPPY();
+  MAKE_VALGRIND_HAPPY(uv_default_loop());
   return 0;
 }
 
@@ -46,24 +46,24 @@ TEST_IMPL(loop_backend_timeout) {
   /* The default loop has some internal watchers to initialize. */
   loop->active_handles++;
   r = uv_run(loop, UV_RUN_NOWAIT);
-  ASSERT_EQ(r, 1);
+  ASSERT_EQ(1, r);
   loop->active_handles--;
-  ASSERT_EQ(uv_loop_alive(loop), 0);
+  ASSERT_OK(uv_loop_alive(loop));
 
   r = uv_timer_init(loop, &timer);
-  ASSERT_EQ(r, 0);
+  ASSERT_OK(r);
 
-  ASSERT_EQ(uv_loop_alive(loop), 0);
-  ASSERT_EQ(uv_backend_timeout(loop), 0);
+  ASSERT_OK(uv_loop_alive(loop));
+  ASSERT_OK(uv_backend_timeout(loop));
 
   r = uv_timer_start(&timer, cb, 1000, 0); /* 1 sec */
-  ASSERT_EQ(r, 0);
-  ASSERT_EQ(uv_backend_timeout(loop), 1000);
+  ASSERT_OK(r);
+  ASSERT_EQ(1000, uv_backend_timeout(loop));
 
   r = uv_run(loop, UV_RUN_DEFAULT);
-  ASSERT_EQ(r, 0);
-  ASSERT_EQ(uv_backend_timeout(loop), 0);
+  ASSERT_OK(r);
+  ASSERT_OK(uv_backend_timeout(loop));
 
-  MAKE_VALGRIND_HAPPY();
+  MAKE_VALGRIND_HAPPY(loop);
   return 0;
 }
