@@ -27,7 +27,7 @@
 #include <string.h>
 
 #define CHECK_HANDLE(handle) \
-  ASSERT((uv_udp_t*)(handle) == &server || (uv_udp_t*)(handle) == &client)
+  ASSERT_NE((uv_udp_t*)(handle) == &server || (uv_udp_t*)(handle) == &client, 0)
 
 static uv_udp_t server;
 static uv_udp_t client;
@@ -45,7 +45,7 @@ static void alloc_cb(uv_handle_t* handle,
                      uv_buf_t* buf) {
   static char slab[65536];
   CHECK_HANDLE(handle);
-  ASSERT(suggested_size <= sizeof(slab));
+  ASSERT_LE(suggested_size, sizeof(slab));
   buf->base = slab;
   buf->len = sizeof(slab);
 }
@@ -61,20 +61,20 @@ static void close_cb(uv_handle_t* handle) {
 static void cl_send_cb(uv_udp_send_t* req, int status) {
   int r;
 
-  ASSERT(req != NULL);
-  ASSERT(status == 0);
+  ASSERT_NOT_NULL(req);
+  ASSERT_OK(status);
   CHECK_HANDLE(req->handle);
   if (++cl_send_cb_called == 1) {
     uv_udp_connect(&client, NULL);
     r = uv_udp_send(req, &client, &buf, 1, NULL, cl_send_cb);
-    ASSERT(r == UV_EDESTADDRREQ);
+    ASSERT_EQ(r, UV_EDESTADDRREQ);
     r = uv_udp_send(req,
                     &client,
                     &buf,
                     1,
                     (const struct sockaddr*) &lo_addr,
                     cl_send_cb);
-    ASSERT(r == 0);
+    ASSERT_OK(r);
   }
 
 }
@@ -86,9 +86,9 @@ static void sv_recv_cb(uv_udp_t* handle,
                        const struct sockaddr* addr,
                        unsigned flags) {
   if (nread > 0) {
-    ASSERT(nread == 4);
-    ASSERT(addr != NULL);
-    ASSERT(memcmp("EXIT", rcvbuf->base, nread) == 0);
+    ASSERT_EQ(4, nread);
+    ASSERT_NOT_NULL(addr);
+    ASSERT_OK(memcmp("EXIT", rcvbuf->base, nread));
     if (++sv_recv_cb_called == 4) {
       uv_close((uv_handle_t*) &server, close_cb);
       uv_close((uv_handle_t*) &client, close_cb);
@@ -98,9 +98,8 @@ static void sv_recv_cb(uv_udp_t* handle,
 
 
 TEST_IMPL(udp_connect) {
-#if defined(__PASE__)
-  RETURN_SKIP(
-      "IBMi PASE's UDP connection can not be disconnected with AF_UNSPEC.");
+#if defined(__OpenBSD__)
+  RETURN_SKIP("Test does not currently work in OpenBSD");
 #endif
   uv_udp_send_t req;
   struct sockaddr_in ext_addr;
@@ -108,90 +107,90 @@ TEST_IMPL(udp_connect) {
   int r;
   int addrlen;
 
-  ASSERT(0 == uv_ip4_addr("0.0.0.0", TEST_PORT, &lo_addr));
+  ASSERT_OK(uv_ip4_addr("0.0.0.0", TEST_PORT, &lo_addr));
 
   r = uv_udp_init(uv_default_loop(), &server);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
 
   r = uv_udp_bind(&server, (const struct sockaddr*) &lo_addr, 0);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
 
   r = uv_udp_recv_start(&server, alloc_cb, sv_recv_cb);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
 
   r = uv_udp_init(uv_default_loop(), &client);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
 
   buf = uv_buf_init("EXIT", 4);
 
-  // connect() to INADDR_ANY fails on Windows wih WSAEADDRNOTAVAIL
-  ASSERT_EQ(0, uv_ip4_addr("0.0.0.0", TEST_PORT, &tmp_addr));
+  /* connect() to INADDR_ANY fails on Windows with WSAEADDRNOTAVAIL */
+  ASSERT_OK(uv_ip4_addr("0.0.0.0", TEST_PORT, &tmp_addr));
   r = uv_udp_connect(&client, (const struct sockaddr*) &tmp_addr);
 #ifdef _WIN32
   ASSERT_EQ(r, UV_EADDRNOTAVAIL);
 #else
-  ASSERT_EQ(r, 0);
+  ASSERT_OK(r);
   r = uv_udp_connect(&client, NULL);
-  ASSERT_EQ(r, 0);
+  ASSERT_OK(r);
 #endif
 
-  ASSERT(0 == uv_ip4_addr("8.8.8.8", TEST_PORT, &ext_addr));
-  ASSERT(0 == uv_ip4_addr("127.0.0.1", TEST_PORT, &lo_addr));
+  ASSERT_OK(uv_ip4_addr("8.8.8.8", TEST_PORT, &ext_addr));
+  ASSERT_OK(uv_ip4_addr("127.0.0.1", TEST_PORT, &lo_addr));
 
   r = uv_udp_connect(&client, (const struct sockaddr*) &lo_addr);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
   r = uv_udp_connect(&client, (const struct sockaddr*) &ext_addr);
-  ASSERT(r == UV_EISCONN);
+  ASSERT_EQ(r, UV_EISCONN);
 
   addrlen = sizeof(tmp_addr);
   r = uv_udp_getpeername(&client, (struct sockaddr*) &tmp_addr, &addrlen);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
 
   /* To send messages in connected UDP sockets addr must be NULL */
   r = uv_udp_try_send(&client, &buf, 1, (const struct sockaddr*) &lo_addr);
-  ASSERT(r == UV_EISCONN);
+  ASSERT_EQ(r, UV_EISCONN);
   r = uv_udp_try_send(&client, &buf, 1, NULL);
-  ASSERT(r == 4);
+  ASSERT_EQ(4, r);
   r = uv_udp_try_send(&client, &buf, 1, (const struct sockaddr*) &ext_addr);
-  ASSERT(r == UV_EISCONN);
+  ASSERT_EQ(r, UV_EISCONN);
 
   r = uv_udp_connect(&client, NULL);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
   r = uv_udp_connect(&client, NULL);
-  ASSERT(r == UV_ENOTCONN);
+  ASSERT_EQ(r, UV_ENOTCONN);
 
   addrlen = sizeof(tmp_addr);
   r = uv_udp_getpeername(&client, (struct sockaddr*) &tmp_addr, &addrlen);
-  ASSERT(r == UV_ENOTCONN);
+  ASSERT_EQ(r, UV_ENOTCONN);
 
   /* To send messages in disconnected UDP sockets addr must be set */
   r = uv_udp_try_send(&client, &buf, 1, (const struct sockaddr*) &lo_addr);
-  ASSERT(r == 4);
+  ASSERT_EQ(4, r);
   r = uv_udp_try_send(&client, &buf, 1, NULL);
-  ASSERT(r == UV_EDESTADDRREQ);
+  ASSERT_EQ(r, UV_EDESTADDRREQ);
 
 
   r = uv_udp_connect(&client, (const struct sockaddr*) &lo_addr);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
   r = uv_udp_send(&req,
                   &client,
                   &buf,
                   1,
                   (const struct sockaddr*) &lo_addr,
                   cl_send_cb);
-  ASSERT(r == UV_EISCONN);
+  ASSERT_EQ(r, UV_EISCONN);
   r = uv_udp_send(&req, &client, &buf, 1, NULL, cl_send_cb);
-  ASSERT(r == 0);
+  ASSERT_OK(r);
 
   uv_run(uv_default_loop(), UV_RUN_DEFAULT);
 
-  ASSERT(close_cb_called == 2);
-  ASSERT(sv_recv_cb_called == 4);
-  ASSERT(cl_send_cb_called == 2);
+  ASSERT_EQ(2, close_cb_called);
+  ASSERT_EQ(4, sv_recv_cb_called);
+  ASSERT_EQ(2, cl_send_cb_called);
 
-  ASSERT(client.send_queue_size == 0);
-  ASSERT(server.send_queue_size == 0);
+  ASSERT_OK(client.send_queue_size);
+  ASSERT_OK(server.send_queue_size);
 
-  MAKE_VALGRIND_HAPPY();
+  MAKE_VALGRIND_HAPPY(uv_default_loop());
   return 0;
 }
